summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/output.cc
diff options
context:
space:
mode:
authorreaverb <reaverb.Crawl@gmail.com>2014-06-08 16:18:35 -0400
committerreaverb <reaverb.Crawl@gmail.com>2014-06-08 16:18:35 -0400
commit93c65a706663ace1d21d71fa2d87abffd7122dac (patch)
treea422c7ca314324f5a81fc2b587ae83b6d8b36ed9 /crawl-ref/source/output.cc
parentaf201b283f1697b378237c57019247cc90b82544 (diff)
downloadcrawl-ref-93c65a706663ace1d21d71fa2d87abffd7122dac.tar.gz
crawl-ref-93c65a706663ace1d21d71fa2d87abffd7122dac.zip
Redraw player EV after a Str change (#8658)
Diffstat (limited to 'crawl-ref/source/output.cc')
-rw-r--r--crawl-ref/source/output.cc7
1 files changed, 5 insertions, 2 deletions
diff --git a/crawl-ref/source/output.cc b/crawl-ref/source/output.cc
index 0250d57ed2..4ccdf92601 100644
--- a/crawl-ref/source/output.cc
+++ b/crawl-ref/source/output.cc
@@ -1237,9 +1237,12 @@ void print_stats()
cursor_control coff(false);
textcolor(LIGHTGREY);
- // Displayed evasion is now tied to dex.
- if (you.redraw_stats[STAT_DEX])
+ // Displayed evasion is tied to dex/str.
+ if (you.redraw_stats[STAT_DEX]
+ || you.redraw_stats[STAT_STR])
+ {
you.redraw_evasion = true;
+ }
if (HP_Bar.wants_redraw())
you.redraw_hit_points = true;